==> formbuilder-1.2.0.tgz: package/README.md <==
# Creat formbuilder

[![npm version][npm-version-src]][npm-version-href]
[![npm downloads][npm-downloads-src]][npm-downloads-href]
[![License][license-src]][license-href]
[![Nuxt][nuxt-src]][nuxt-href]

:warning: This package is under development stay tuned. :warning:

Nuxt3 Typescript Simple formbuilder

- [✨ &nbsp;Release Notes](/CHANGELOG.md)

## Features

<!-- Highlight some of the features your module provide here -->

## Quick Setup

1. Add `@creatiwity/formbuilder` dependency to your project

```bash
# Using pnpm
pnpm add @creatiwity/formbuilder

# Using yarn
yarn add @creatiwity/formbuilder

# Using npm
npm install @creatiwity/formbuilder
```

2. Add `@creatiwity/formbuilder` to the `modules` section of `nuxt.config.ts`

```js
export default defineNuxtConfig({
  modules: ["@creatiwity/formbuilder"],
});
```

That's it! You can now use Creat formbuilder in your Nuxt app ✨

## Recommended Usage

- First define one or multiple factories in which you'll specify a component of your own to be instantiate in the formbuilder.
- Use your factories to construct your form 'elements'
- Validation is based on Vuelidate
- Errors can be customized

```ts
export interface FieldInputData extends CommonFieldData {
  key: string;
  label: string;
  type: string;
  disabled?: boolean;
}

function useInputField(data: FieldInputData): FormElementItem {
  return {
    key: data.key,
    props: <FieldInputData>() =>
      ({
        key: data.key,
        name: data.key,
        label: data.label,
        type: data.type,
        isReadOnly: data.isReadOnly,
        isHidden: data.isHidden,
        mandatory: data.mandatory,
      } as FieldInputData),
    component: FormInput as DefineComponent<{}, {}, any>,
    validation: data.validation,
  };
}

const MyForm = (): FormElement => ({
  sets: [
    {
      title: "First Section",
      description: "Section description",
      elements: [
        useInputField({
          key: "name",
          label: "Nom",
          type: "text",
          isReadOnly: (data) => data === "test",
          validation: () => {
            return { required, minLength: minLength(3) };
          },
        }),
      ],
    },
  ],
});

const myForm = ref<MyFormType>({
  name: "aaaa",
});

const myFormElement = MyForm();

const errors: FormElementError = {
  name: {
    required: "Le nom est requis",
  },
};
```

```html
<div>
  <CreatFormBuilder
    id="myForm"
    v-model="myForm"
    :form-element="myFormElement"
    :errors="errors"
  />
</div>
```

## Options

| props    | type             | optional | usage                           |
| -------- | ---------------- | -------- | ------------------------------- |
| readOnly | boolean          | yes      | will make all the form readonly |
| ctaLabel | string           | yes      | Label for the submit button     |
| ctaClass | string           | yes      | class for the submit button     |
| errors   | FormElementError | yes      | Your custom errors              |

<!-- Badges -->

[npm-version-src]: https://img.shields.io/npm/v/@creatiwity/formbuilder/latest.svg?style=flat&colorA=18181B&colorB=28CF8D
[npm-version-href]: https://npmjs.com/package/@creatiwity/formbuilder
[npm-downloads-src]: https://img.shields.io/npm/dm/@creatiwity/formbuilder.svg?style=flat&colorA=18181B&colorB=28CF8D
[npm-downloads-href]: https://npmjs.com/package/@creatiwity/formbuilder
[license-src]: https://img.shields.io/npm/l/@creatiwity/formbuilder.svg?style=flat&colorA=18181B&colorB=28CF8D
[license-href]: https://npmjs.com/package/@creatiwity/formbuilder
[nuxt-src]: https://img.shields.io/badge/Nuxt-18181B?logo=nuxt.js
[nuxt-href]: https://nuxt.com

==> formbuilder-1.3.0.tgz: package/README.md <==
# Creat formbuilder

[![npm version][npm-version-src]][npm-version-href]
[![npm downloads][npm-downloads-src]][npm-downloads-href]
[![License][license-src]][license-href]
[![Nuxt][nuxt-src]][nuxt-href]

:warning: This package is under development stay tuned. :warning:

Nuxt3 Typescript Simple formbuilder

- [✨ &nbsp;Release Notes](/CHANGELOG.md)

## Features

<!-- Highlight some of the features your module provide here -->

## Quick Setup

1. Add `@creatiwity/formbuilder` dependency to your project

```bash
# Using pnpm
pnpm add @creatiwity/formbuilder

# Using yarn
yarn add @creatiwity/formbuilder

# Using npm
npm install @creatiwity/formbuilder
```

2. Add `@creatiwity/formbuilder` to the `modules` section of `nuxt.config.ts`

```js
export default defineNuxtConfig({
  modules: ["@creatiwity/formbuilder"],
});
```

That's it! You can now use Creat formbuilder in your Nuxt app ✨

## Recommended Usage

- First define one or multiple factories in which you'll specify a component of your own to be instantiate in the formbuilder.
- Use your factories to construct your form 'elements'
- Validation is based on Vuelidate
- Errors can be customized

```ts
export interface FieldInputProps {
  key: string;
  label: string;
  type: string;
  disabled?: boolean;
}

export function useInputField(
  data: FieldInputProps,
  options: FormOptions<FormModel>
): FormElementItem<FieldInputProps, never, FormModel> {
  return {
    key: data.key,
    props: () => ({
      key: data.key,
      name: data.key,
      label: data.label,
      type: data.type,
    }),
    component: FormInput,
    validation: options.validation,
    isReadOnly: options.isReadOnly,
    isHidden: options.isHidden,
    mandatory: options.mandatory ?? false,
  };
}

const MyForm = (): FormElement<FieldInputProps, never, FormModel> => ({
  sets: [
    {
      title: "First Section",
      description: "Section description",
      elements: [
        useInputField(
          {
            key: "name",
            label: "Nom",
            type: "text",
          },
          {
            validation: () => {
              return { required, minLength: minLength(3) };
            },
            isReadOnly: (data) => data.name === "test",
          }
        ),
      ],
    },
  ],
});

const myForm = ref<FormModel>({
  name: "aaaa",
});

const myFormElement = MyForm();

const errors: FormElementError = {
  name: {
    required: "Le nom est requis",
  },
};
```

```html
<div>
  <CreatFormBuilder
    id="myForm"
    v-model="myForm"
    :form-element="myFormElement"
    :errors="errors"
  />
</div>
```

## Options

| props         | type             | optional | usage              |
| ------------- | ---------------- | -------- | ------------------ |
| form-elements | FormElement      | no       | Your form schema   |
| errors        | FormElementError | yes      | Your custom errors |

<!-- Badges -->

[npm-version-src]: https://img.shields.io/npm/v/@creatiwity/formbuilder/latest.svg?style=flat&colorA=18181B&colorB=28CF8D
[npm-version-href]: https://npmjs.com/package/@creatiwity/formbuilder
[npm-downloads-src]: https://img.shields.io/npm/dm/@creatiwity/formbuilder.svg?style=flat&colorA=18181B&colorB=28CF8D
[npm-downloads-href]: https://npmjs.com/package/@creatiwity/formbuilder
[license-src]: https://img.shields.io/npm/l/@creatiwity/formbuilder.svg?style=flat&colorA=18181B&colorB=28CF8D
[license-href]: https://npmjs.com/package/@creatiwity/formbuilder
[nuxt-src]: https://img.shields.io/badge/Nuxt-18181B?logo=nuxt.js
[nuxt-href]: https://nuxt.com
